@@ -2,7 +2,7 @@ package Data::Sah::Coerce;
 
 our $DATE = '2020-01-02'; # DATE
 our $DIST = 'Data-Sah-Coerce'; # DIST
-our $VERSION = '0.042'; # VERSION
+our $VERSION = '0.043'; # VERSION
 
 use 5.010001;
 use strict;
@@ -143,7 +143,7 @@ Data::Sah::Coerce - Coercion rules for Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.042 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2020-01-02.
+This document describes version 0.043 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2020-01-02.
 
 =head1 SYNOPSIS
 
@@ -153,8 +153,8 @@ This document describes version 0.042 of Data::Sah::Coerce (from Perl distributi
  my $c = gen_coercer(
      type               => 'date',
      coerce_to          => 'DateTime',
-     coerce_rules       => ['str_alami'],  # explicitly enable a rule, etc
-     # return_type      => 'str+val',      # default is 'val'
+     coerce_rules       => ['From_str::natural'],  # explicitly enable a rule, etc
+     # return_type      => 'str+val',              # default is 'val'
  );
 
  my $val = $c->(123);          # unchanged, 123
@@ -230,20 +230,18 @@ put further back (lower priority, higher number).
 
 List the other rules or rule patterns that are precluded by this rule. Rules
 that are mutually exclusive or pure alternatives to one another (e.g. date
-coercien rules L<str_alami|Data::Sah::Coerce::date::str_alami> vs
-L<str_alami|Data::Sah::Coerce::date::str_alami> both parse natural language date
-string; there is usually little to none of usefulness in using both; besides,
-both rules match all string and dies when failing to parse the string. So in
-C<str_natural> rule, you'll find this metadata:
+coercien rules
+L<From_str::natural|Data::Sah::Coerce::To_date::From_str::natural> vs
+L<From_str::flexible|Data::Sah::Coerce::To_date::From_str::flexible> both parse
+natural language date string; there is usually little to none of usefulness in
+using both; besides, both rules match all string and dies when failing to parse
+the string. So in C<From_str::natural> rule, you'll find this metadata:
 
- precludes => [qr/\AFrom_str::Alami(_.+)?\z/]
+ precludes => [qr/\A(From_str::alami(_.+)?|From_str::natural)\z/]
 
-and in C<From_str::Alami> rule you'll find this metadata:
+and in C<From_str::flexible> rule you'll find this metadata:
 
- precludes => [qr/\AFrom_str::Alami(_.+)?\z/, 'From_str::Natural']
-
-Note that the C<From_str::Alami> rule also precludes other C<From_str::Alami_*>
-rules (like C<From_str::Alami_EN> and C<From_str::Alami_ID>).
+ precludes => [qr/\A(From_str::alami(_.+)?|From_str::flexible)\z/]
 
 Also note that rules which are specifically requested to be used (e.g. using
 C<x.perl.coerce_rules> attribute in Sah schema) will still be precluded.
